import re
from typing import Final

import pyperclip
from beni import bcolor, btask
from beni.bfunc import syncCall

app: Final = btask.app


@app.command()
@syncCall
async def take_asin():
    '从Markdown文档内容中获取所有 ASIN（使用剪切板传递数据）'
    content = pyperclip.paste()
    assert content, '剪切板没有内容'

    dataList: list[str] = re.findall(r'\[([0-9A-Z]+)\]', content)
    assert dataList, '没有找到 ASIN'

    # 去除重复的 ASIN，去重后保持原有顺序
    dataList = list(dict.fromkeys(dataList))

    for asin in dataList:
        print(asin)

    content = '  '.join(dataList)
    pyperclip.copy(content)
    bcolor.printGreen('已复制到剪贴板')
    bcolor.printGreen('OK')



from __future__ import annotations

from typing import Final

from beni import btask
from beni.bfunc import syncCall

app: Final = btask.app


@app.command()
@syncCall
async def hello():
    print('hello')


@app.command()
@syncCall
async def bye():
    print('bye')



import getpass
from typing import Any

from beni import bcache, bcrypto


@bcache.cache
async def getQiniu() -> tuple[str, str]:
    content = '7xOuA0FPCndTWcWmWLbqklQTqLTAhuEw9CarRTBYhWQ/g8wPxktw6VAiu50TLv49D1L8oCVfGafsowYDZw/prF6NQwCluPcCMy5JfdC9sKauvuZa51Nsf6PTR1UIyU8ZLUSzH+Ec2Ufcz/yAZCrcAtn63zMHNu3tTAVcZNPL597lSHdSRkpmDR8CaoUh/raH/Q=='
    data = _getData(content)
    return data['ak'], data['sk']


def _getData(content: str) -> dict[str, Any]:
    index = content.find(' ')
    if index > -1:
        tips = f'请输入密码（{content[:index]}）：'
    else:
        tips = '请输入密码：'
    while True:
        try:
            pwd = getpass.getpass(tips)
            return bcrypto.decryptJson(content, pwd)
        except KeyboardInterrupt:
            raise Exception('操作取消')
        except BaseException:
            pass



from __future__ import annotations

import re
from typing import Final

import pyperclip
import typer
from beni import bcolor, btask
from beni.bfunc import syncCall

app: Final = btask.app


@app.command()
@syncCall
async def tidy_title(
    keys: list[str] = typer.Argument(None, help='关键词')
):
    '使用所有商品报告找出所有的标题，排序输出（使用粘贴板）'
    keys = keys or []
    content = pyperclip.paste()
    lineAry = [(x.split('\t').pop(0), x.split('\t').pop(3)) for x in content.strip().split('\n')]
    # gmc|chevrolet|chevy
    if keys:
        pattern = re.compile(rf'\b({'|'.join(keys)})\b', re.IGNORECASE)
        lineAry = list(filter(lambda x: pattern.search(x[0]) and x[0].endswith(')'), lineAry))
    lineAry = [(re.sub(r'\s*\([^)]*\)$', '', x[0]), x[1]) for x in lineAry]

    lineDict: dict[str, tuple[str, str]] = {}
    for line in lineAry:
        lineDict[line[0]] = line
    lineAry = [x for x in lineDict.values()]
    lineAry.sort(key=lambda x: x[0])

    content = '\n'.join([f'{x[0]}\t\t{x[1]}' for x in lineAry])
    pyperclip.copy(content)
    print(content)
    bcolor.printGreen('OK')
